0.0.3
---

* Allow project to bootstrap itself with tox
  https://github.com/GoogleCloudPlatform/artifact-registry-python-tools/issues/7
* Update classname and python endpoints

0.0.2
---

* Fixed None reference when parsing a service which is not a proper URL
  https://github.com/GoogleCloudPlatform/artifact-registry-python-tools/issues/4
